@@ -1,4 +1,6 @@
+from ast import Call
 import math
+from matplotlib import pyplot
 from typing import Callable, Dict, List, Union
 
 class Булева_формула: # Булева формула, операндами которой являются нечёткие высказывания
@@ -258,7 +260,7 @@ class Модель:
         
 class Нечёткий_вывод:
 
-    def Вывод(self, Модель = Модель()):
+    def Вывод(self, Модель = Модель(),Чтение_файлов = True):
         def Формирование_базы_правил():
             def Считать_таблицу(Функция, Имя_файла):
                 try:
@@ -373,7 +375,8 @@ class Нечёткий_вывод:
                 if ЛП.Значение is None:
                     ЛП.Дефаззифицированное_значение = Метод(ЛП)
 
-        Формирование_базы_правил()
+        if Чтение_файлов:
+            Формирование_базы_правил()
        
         while True:
             Использованность_правил = [not x.Не_использовано for x in self.Правила]
@@ -390,7 +393,7 @@ class Нечёткий_вывод:
         for ЛП in self.Лингвистические_переменные:
             try:
                 if hasattr(ЛП,"Аккумулированная_функция"): 
-                    print(ЛП.Имя + ": " + ЛП.Дефаззифицированное_значение)
+                    print(ЛП.Дефаззифицированное_значение)
             except:
                 print("Ошибка")  
    
